@@ -3,7 +3,7 @@
 * Nagios check_apt plugin
 * 
 * License: GPL
-* Copyright (c) 2006-2008 Nagios Plugins Development Team
+* Copyright (c) 2006-2014 Nagios Plugins Development Team
 * 
 * Original author: Sean Finney
 * 
@@ -30,8 +30,8 @@
 *****************************************************************************/
 
 const char *progname = "check_apt";
-const char *copyright = "2006-2008";
-const char *email = "nagiosplug-devel@lists.sourceforge.net";
+const char *copyright = "2006-2014";
+const char *email = "devel@nagios-plugins.org";
 
 #include "common.h"
 #include "runcmd.h"
@@ -124,7 +124,7 @@ int main (int argc, char **argv) {
 	       (stderr_warning)?" warnings detected":"",
 	       (stderr_warning && exec_warning)?",":"",
 	       (exec_warning)?" errors detected":"",
-	       (stderr_warning||exec_warning)?". run with -v for information.":"",
+	       (stderr_warning||exec_warning)?".":"",
 	        packages_available,
 		   sec_count
 	       );
@@ -168,7 +168,7 @@ int process_arguments (int argc, char **argv) {
 			verbose++;
 			break;
 		case 't':
-			timeout_interval=atoi(optarg);
+			timeout_interval=parse_timeout_string(optarg);
 			break;
 		case 'd':
 			upgrade=DIST_UPGRADE;
@@ -223,6 +223,9 @@ int run_upgrade(int *pkgcount, int *secpkgcount){
 	regex_t ireg, ereg, sreg;
 	char *cmdline=NULL, rerrbuf[64];
 
+	/* initialize ereg as it is possible it is printed while uninitialized */
+	memset(&ereg, '\0', sizeof(ereg.buffer));
+
 	if(upgrade==NO_UPGRADE) return STATE_OK;
 
 	/* compile the regexps */
@@ -430,7 +433,7 @@ print_help (void)
   printf(UT_HELP_VRSN);
   printf(UT_EXTRA_OPTS);
 
-  printf(UT_TIMEOUT, timeout_interval);
+  printf(UT_PLUG_TIMEOUT, timeout_interval);
 
   printf (" %s\n", "-U, --upgrade=OPTS");
   printf ("    %s\n", _("[Default] Perform an upgrade.  If an optional OPTS argument is provided,"));
