@@ -28,8 +28,8 @@
 * 
 *****************************************************************************/
 
-#ifndef _NETUTILS_H_
-#define _NETUTILS_H_
+#ifndef NAGIOS_NETUGILS_H_INCLUDED_
+#define NAGIOS_NETUGILS_H_INCLUDED_
 
 #include "common.h"
 #include "utils.h"
@@ -41,7 +41,7 @@
 # include <sys/un.h>
 # ifndef UNIX_PATH_MAX
    /* linux uses this, on sun it's hard-coded at 108 without a define */
-#  define UNIX_PATH_MAX 108
+#  define UNIX_PATH_MAX 104
 # endif /* UNIX_PATH_MAX */
 #endif /* HAVE_SYS_UN_H */
 
@@ -81,8 +81,6 @@ void host_or_die(const char *str);
 #  define is_hostname(addr) resolve_host_or_addr(addr, AF_INET)
 #endif
 
-extern unsigned int socket_timeout;
-extern unsigned int socket_timeout_state;
 extern int econn_refuse_state;
 extern int was_refused;
 extern int address_family;
@@ -91,6 +89,16 @@ RETSIGTYPE socket_timeout_alarm_handler (int) __attribute__((noreturn));
 
 /* SSL-Related functionality */
 #ifdef HAVE_SSL
+#  define MP_SSLv2 1
+#  define MP_SSLv3 2
+#  define MP_TLSv1 3
+#  define MP_TLSv1_1 4
+#  define MP_TLSv1_2 5
+#  define MP_SSLv2_OR_NEWER 6
+#  define MP_SSLv3_OR_NEWER 7
+#  define MP_TLSv1_OR_NEWER 8
+#  define MP_TLSv1_1_OR_NEWER 9
+#  define MP_TLSv1_2_OR_NEWER 10
 /* maybe this could be merged with the above np_net_connect, via some flags */
 int np_net_ssl_init(int sd);
 int np_net_ssl_init_with_hostname(int sd, char *host_name);
@@ -102,4 +110,4 @@ int np_net_ssl_read(void *buf, int num);
 int np_net_ssl_check_cert(int days_till_exp_warn, int days_till_exp_crit);
 #endif /* HAVE_SSL */
 
-#endif /* _NETUTILS_H_ */
+#endif /* NAGIOS_NETUGILS_H_INCLUDED_ */
